@@ -1,6 +1,8 @@
 #!/usr/bin/env python3
 """
-Windows PE EXE icon extractor.
+Windows Portable Executable (PE) icon extractor.
+
+.. include:: ../LIB-USAGE.md
 """
 
 import io
@@ -25,19 +27,21 @@ except ImportError:
     logger.info('icoextract: failed to read program version')
 
 class IconExtractorError(Exception):
-    pass
+    """Superclass for exceptions raised by IconExtractor."""
+
 class NoIconsAvailableError(IconExtractorError):
-    pass
+    """Exception raised when the input program has no icon resources."""
+
 class InvalidIconDefinitionError(IconExtractorError):
-    pass
+    """Exception raised when the input program has an invalid icon resource."""
 
 class IconExtractor():
     def __init__(self, filename=None, data=None):
         """
-        Loads an executable from the given filename or data (raw bytes).
-        As with pefile, if both filename and data are given, filename takes precedence.
+        Loads an executable from the given `filename` or `data` (raw bytes).
+        As with pefile, if both `filename` and `data` are given, `filename` takes precedence.
 
-        If the executable has contains no icons, this will raise NoIconsAvailableError.
+        If the executable has contains no icons, this will raise `NoIconsAvailableError`.
         """
         # Use fast loading and explicitly load the RESOURCE directory entry. This saves a LOT of time
         # on larger files
@@ -140,19 +144,29 @@ class IconExtractor():
             group_icon, icon_data = datapair
             fd.write(icon_data)
 
-    def export_icon(self, fname, num=0):
+    def export_icon(self, filename, num=0):
         """
-        Writes ICO data of the requested group icon ID to fname.
+        Exports ICO data for the requested group icon (`num`) to `filename`.
         """
-        with open(fname, 'wb') as f:
+        with open(filename, 'wb') as f:
             self._write_ico(f, num=num)
 
     def get_icon(self, num=0):
         """
-        Returns ICO data as a BytesIO() instance, containing the requested group icon ID.
+        Exports ICO data for the requested group icon (`num`) as a `io.BytesIO` instance.
         """
         f = io.BytesIO()
         self._write_ico(f, num=num)
         return f
 
-__all__ = ['IconExtractor']
+__all__ = [
+    'IconExtractor',
+    'IconExtractorError',
+    'NoIconsAvailableError',
+    'InvalidIconDefinitionError'
+]
+
+__pdoc__ = {
+    'scripts': False,
+    'version': False,
+}
